@@ -9,7 +9,6 @@ from pymodbus.constants import ModbusStatus
 from pymodbus.pdu import ModbusRequest
 from pymodbus.pdu import ModbusResponse
 from pymodbus.pdu import ModbusExceptions as merror
-from pymodbus.exceptions import ParameterException
 from pymodbus.utilities import pack_bitstring, unpack_bitstring
 
 #---------------------------------------------------------------------------#
@@ -20,6 +19,7 @@ from pymodbus.utilities import pack_bitstring, unpack_bitstring
 _turn_coil_on  = struct.pack(">H", ModbusStatus.On)
 _turn_coil_off = struct.pack(">H", ModbusStatus.Off)
 
+
 class WriteSingleCoilRequest(ModbusRequest):
     '''
     This function code is used to write a single output to either ON or OFF
@@ -48,7 +48,7 @@ class WriteSingleCoilRequest(ModbusRequest):
         '''
         ModbusRequest.__init__(self, **kwargs)
         self.address = address
-        self.value = True if value else False
+        self.value = bool(value)
 
     def encode(self):
         ''' Encodes write coil request
@@ -56,7 +56,8 @@ class WriteSingleCoilRequest(ModbusRequest):
         :returns: The byte encoded message
         '''
         result  = struct.pack('>H', self.address)
-        result += _turn_coil_on if self.value else _turn_coil_off
+        if self.value: result += _turn_coil_on
+        else: result += _turn_coil_off
         return result
 
     def decode(self, data):
@@ -65,7 +66,7 @@ class WriteSingleCoilRequest(ModbusRequest):
         :param data: The packet data to decode
         '''
         self.address, value = struct.unpack('>HH', data)
-        self.value = True if value == ModbusStatus.On else False
+        self.value = (value == ModbusStatus.On)
 
     def execute(self, context):
         ''' Run a write coil request against a datastore
@@ -78,7 +79,7 @@ class WriteSingleCoilRequest(ModbusRequest):
         if not context.validate(self.function_code, self.address, 1):
             return self.doException(merror.IllegalAddress)
 
-        context.setValues(self.function_code, self.address, self.value)
+        context.setValues(self.function_code, self.address, [self.value])
         values = context.getValues(self.function_code, self.address, 1)
         return WriteSingleCoilResponse(self.address, values[0])
 
@@ -89,6 +90,7 @@ class WriteSingleCoilRequest(ModbusRequest):
         '''
         return "WriteCoilRequest(%d, %s) => " % (self.address, self.value)
 
+
 class WriteSingleCoilResponse(ModbusResponse):
     '''
     The normal response is an echo of the request, returned after the coil
@@ -113,7 +115,8 @@ class WriteSingleCoilResponse(ModbusResponse):
         :return: The byte encoded message
         '''
         result  = struct.pack('>H', self.address)
-        result += _turn_coil_on if self.value else _turn_coil_off
+        if self.value: result += _turn_coil_on
+        else: result += _turn_coil_off
         return result
 
     def decode(self, data):
@@ -131,6 +134,7 @@ class WriteSingleCoilResponse(ModbusResponse):
         '''
         return "WriteCoilResponse(%d) => %d" % (self.address, self.value)
 
+
 class WriteMultipleCoilsRequest(ModbusRequest):
     '''
     "This function code is used to force each coil in a sequence of coils to
@@ -203,6 +207,7 @@ class WriteMultipleCoilsRequest(ModbusRequest):
         params = (self.address, len(self.values))
         return "WriteNCoilRequest (%d) => %d " % params
 
+
 class WriteMultipleCoilsResponse(ModbusResponse):
     '''
     The normal response returns the function code, starting address, and
@@ -242,9 +247,9 @@ class WriteMultipleCoilsResponse(ModbusResponse):
         '''
         return "WriteNCoilResponse(%d, %d)" % (self.address, self.count)
 
-#---------------------------------------------------------------------------# 
+#---------------------------------------------------------------------------#
 # Exported symbols
-#---------------------------------------------------------------------------# 
+#---------------------------------------------------------------------------#
 __all__ = [
     "WriteSingleCoilRequest", "WriteSingleCoilResponse",
     "WriteMultipleCoilsRequest", "WriteMultipleCoilsResponse",
