@@ -35,7 +35,9 @@ Another example::
 from twisted.internet import defer, protocol
 from pymodbus.factory import ClientDecoder
 from pymodbus.exceptions import ConnectionException
-from pymodbus.transaction import ModbusSocketFramer, ModbusTransactionManager
+from pymodbus.transaction import ModbusSocketFramer
+from pymodbus.transaction import FifoTransactionManager
+from pymodbus.transaction import DictTransactionManager
 from pymodbus.client.common import ModbusClientMixin
 from twisted.python.failure import Failure
 
@@ -45,11 +47,6 @@ from twisted.python.failure import Failure
 import logging
 _logger = logging.getLogger(__name__)
 
-#---------------------------------------------------------------------------#
-# A manager for the transaction identifiers
-#---------------------------------------------------------------------------#
-_manager = ModbusTransactionManager()
-
 
 #---------------------------------------------------------------------------#
 # Connected Client Protocols
@@ -65,9 +62,11 @@ class ModbusClientProtocol(protocol.Protocol, ModbusClientMixin):
 
         :param framer: The framer to use for the protocol
         '''
-        self.framer = framer or ModbusSocketFramer(ClientDecoder())
-        self._requests = {}
         self._connected = False
+        self.framer = framer or ModbusSocketFramer(ClientDecoder())
+        if isinstance(self.framer, ModbusSocketFramer):
+            self.transaction = DictTransactionManager(self)
+        else: self.transaction = FifoTransactionManager(self)
 
     def connectionMade(self):
         ''' Called upon a successful client connection.
@@ -82,8 +81,8 @@ class ModbusClientProtocol(protocol.Protocol, ModbusClientMixin):
         '''
         _logger.debug("Client disconnected from modbus server: %s" % reason)
         self._connected = False
-        for key in self._requests.keys():
-            self._requests.pop(key).errback(Failure(
+        for tid in self.transaction:
+            self.transaction.getTransaction(tid).errback(Failure(
                 ConnectionException('Connection lost during request')))
 
     def dataReceived(self, data):
@@ -97,7 +96,7 @@ class ModbusClientProtocol(protocol.Protocol, ModbusClientMixin):
         ''' Starts the producer to send the next request to
         consumer.write(Frame(request))
         '''
-        request.transaction_id = _manager.getNextTID()
+        request.transaction_id = self.transaction.getNextTID()
         packet = self.framer.buildPacket(request)
         self.transport.write(packet)
         return self._buildResponse(request.transaction_id)
@@ -109,7 +108,7 @@ class ModbusClientProtocol(protocol.Protocol, ModbusClientMixin):
         '''
         if reply is not None:
             tid = reply.transaction_id
-            handler = self._requests.pop(tid, None)
+            handler = self.transaction.getTransaction(tid)
             if handler:
                 handler.callback(reply)
             else: _logger.debug("Unrequested message: " + str(reply))
@@ -126,7 +125,7 @@ class ModbusClientProtocol(protocol.Protocol, ModbusClientMixin):
                 ConnectionException('Client is not connected')))
 
         d = defer.Deferred()
-        self._requests[tid] = d # TODO add request here as well
+        self.transaction.addTransaction(d, tid)
         return d
 
     #----------------------------------------------------------------------#
@@ -153,7 +152,9 @@ class ModbusUdpClientProtocol(protocol.DatagramProtocol, ModbusClientMixin):
         :param framer: The framer to use for the protocol
         '''
         self.framer = framer or ModbusSocketFramer(ClientDecoder())
-        self._requests = {}
+        if isinstance(self.framer, ModbusSocketFramer):
+            self.transaction = DictTransactionManager(self)
+        else: self.transaction = FifoTransactionManager(self)
 
     def datagramReceived(self, data, (host, port)):
         ''' Get response, check for valid message, decode result
@@ -167,7 +168,7 @@ class ModbusUdpClientProtocol(protocol.DatagramProtocol, ModbusClientMixin):
         ''' Starts the producer to send the next request to
         consumer.write(Frame(request))
         '''
-        request.transaction_id = _manager.getNextTID()
+        request.transaction_id = self.transaction.getNextTID()
         packet = self.framer.buildPacket(request)
         self.transport.write(packet)
         return self._buildResponse(request.transaction_id)
@@ -179,7 +180,7 @@ class ModbusUdpClientProtocol(protocol.DatagramProtocol, ModbusClientMixin):
         '''
         if reply is not None:
             tid = reply.transaction_id
-            handler = self._requests.pop(tid, None)
+            handler = self.transaction.getTransaction(tid)
             if handler:
                 handler.callback(reply)
             else: _logger.debug("Unrequested message: " + str(reply))
@@ -192,7 +193,7 @@ class ModbusUdpClientProtocol(protocol.DatagramProtocol, ModbusClientMixin):
         :returns: A defer linked to the latest request
         '''
         d = defer.Deferred()
-        self._requests[tid] = d # TODO add request here as well
+        self.transaction.addTransaction(d, tid)
         return d
 
 
