@@ -5,7 +5,8 @@ from pymodbus.constants import Defaults
 from pymodbus.factory import ClientDecoder
 from pymodbus.exceptions import NotImplementedException, ParameterException
 from pymodbus.exceptions import ConnectionException
-from pymodbus.transaction import ModbusTransactionManager
+from pymodbus.transaction import FifoTransactionManager
+from pymodbus.transaction import DictTransactionManager
 from pymodbus.transaction import ModbusSocketFramer, ModbusBinaryFramer
 from pymodbus.transaction import ModbusAsciiFramer, ModbusRtuFramer
 from pymodbus.client.common import ModbusClientMixin
@@ -34,7 +35,9 @@ class BaseModbusClient(ModbusClientMixin):
         :param framer: The modbus framer implementation to use
         '''
         self.framer = framer
-        self.transaction = ModbusTransactionManager(self)
+        if isinstance(self.framer, ModbusSocketFramer):
+            self.transaction = DictTransactionManager(self)
+        else: self.transaction = FifoTransactionManager(self)
 
     #-----------------------------------------------------------------------#
     # Client interface
@@ -77,9 +80,7 @@ class BaseModbusClient(ModbusClientMixin):
         '''
         if not self.connect():
             raise ConnectionException("Failed to connect[%s]" % (self.__str__()))
-        if self.transaction:
-            return self.transaction.execute(request)
-        raise ConnectionException("Client Not Connected")
+        return self.transaction.execute(request)
 
     #-----------------------------------------------------------------------#
     # The magic methods
@@ -93,14 +94,10 @@ class BaseModbusClient(ModbusClientMixin):
             raise ConnectionException("Failed to connect[%s]" % (self.__str__()))
         return self
 
-    def __exit__(self, type, value, traceback):
+    def __exit__(self, klass, value, traceback):
         ''' Implement the client with exit block '''
         self.close()
 
-    def __del__(self):
-        ''' Class destructor '''
-        self.close()
-
     def __str__(self):
         ''' Builds a string representation of the connection
 
@@ -116,18 +113,19 @@ class ModbusTcpClient(BaseModbusClient):
     ''' Implementation of a modbus tcp client
     '''
 
-    def __init__(self, host='127.0.0.1', port=Defaults.Port):
+    def __init__(self, host='127.0.0.1', port=Defaults.Port, framer=ModbusSocketFramer):
         ''' Initialize a client instance
 
         :param host: The host to connect to (default 127.0.0.1)
         :param port: The modbus port to connect to (default 502)
+        :param framer: The modbus framer to use (default ModbusSocketFramer)
 
         .. note:: The host argument will accept ipv4 and ipv6 hosts
         '''
         self.host = host
         self.port = port
         self.socket = None
-        BaseModbusClient.__init__(self, ModbusSocketFramer(ClientDecoder()))
+        BaseModbusClient.__init__(self, framer(ClientDecoder()))
 
     def connect(self):
         ''' Connect to the modbus tcp server
@@ -137,7 +135,6 @@ class ModbusTcpClient(BaseModbusClient):
         if self.socket: return True
         try:
             self.socket = socket.create_connection((self.host, self.port), Defaults.Timeout)
-            self.transaction = ModbusTransactionManager(self)
         except socket.error, msg:
             _logger.error('Connection to (%s, %s) failed: %s' % \
                 (self.host, self.port, msg))
@@ -188,16 +185,17 @@ class ModbusUdpClient(BaseModbusClient):
     ''' Implementation of a modbus udp client
     '''
 
-    def __init__(self, host='127.0.0.1', port=Defaults.Port):
+    def __init__(self, host='127.0.0.1', port=Defaults.Port, framer=ModbusSocketFramer):
         ''' Initialize a client instance
 
         :param host: The host to connect to (default 127.0.0.1)
         :param port: The modbus port to connect to (default 502)
+        :param framer: The modbus framer to use (default ModbusSocketFramer)
         '''
         self.host = host
         self.port = port
         self.socket = None
-        BaseModbusClient.__init__(self, ModbusSocketFramer(ClientDecoder()))
+        BaseModbusClient.__init__(self, framer(ClientDecoder()))
 
     @classmethod
     def _get_address_family(cls, address):
@@ -208,7 +206,7 @@ class ModbusUdpClient(BaseModbusClient):
         :returns: AF_INET for ipv4 and AF_INET6 for ipv6
         '''
         try:
-            addr = socket.inet_pton(socket.AF_INET6, address)
+            _ = socket.inet_pton(socket.AF_INET6, address)
         except socket.error: # not a valid ipv6 address
             return socket.AF_INET
         return socket.AF_INET6
@@ -308,6 +306,7 @@ class ModbusSerialClient(BaseModbusClient):
         if   method == 'ascii':  return ModbusAsciiFramer(ClientDecoder())
         elif method == 'rtu':    return ModbusRtuFramer(ClientDecoder())
         elif method == 'binary': return ModbusBinaryFramer(ClientDecoder())
+        elif method == 'socket': return ModbusSocketFramer(ClientDecoder())
         raise ParameterException("Invalid framer method requested")
 
     def connect(self):
