@@ -51,6 +51,21 @@ class ServerDecoder(IModbusDecoder):
             WriteSingleCoilRequest,
             ReadWriteMultipleRegistersRequest,
 
+            DiagnosticStatusRequest,
+
+            ReadExceptionStatusRequest,
+            GetCommEventCounterRequest,
+            GetCommEventLogRequest,
+            ReportSlaveIdRequest,
+
+            ReadFileRecordRequest,
+            WriteFileRecordRequest,
+            MaskWriteRegisterRequest,
+            ReadFifoQueueRequest,
+
+            ReadDeviceInformationRequest,
+    ]
+    __sub_function_table = [
             ReturnQueryDataRequest,
             RestartCommunicationsOptionRequest,
             ReturnDiagnosticRegisterRequest,
@@ -69,19 +84,17 @@ class ServerDecoder(IModbusDecoder):
             ClearOverrunCountRequest,
             GetClearModbusPlusRequest,
 
-            ReadExceptionStatusRequest,
-            GetCommEventCounterRequest,
-            GetCommEventLogRequest,
-            ReportSlaveIdRequest,
-
-            ReadFileRecordRequest,
-            WriteFileRecordRequest,
-            MaskWriteRegisterRequest,
-            ReadFifoQueueRequest,
-
             ReadDeviceInformationRequest,
     ]
-    __lookup = dict([(f.function_code, f) for f in __function_table])
+
+    def __init__(self):
+        ''' Initializes the client lookup tables
+        '''
+        functions = set(f.function_code for f in self.__function_table)
+        self.__lookup = dict([(f.function_code, f) for f in self.__function_table])
+        self.__sub_lookup = dict((f, {}) for f in functions)
+        for f in self.__sub_function_table:
+            self.__sub_lookup[f.function_code][f.sub_function_code] = f
 
     def decode(self, message):
         ''' Wrapper to decode a request packet
@@ -101,7 +114,7 @@ class ServerDecoder(IModbusDecoder):
         :param function_code: The function code specified in a frame.
         :returns: The class of the PDU that has a matching `function_code`.
         '''
-        return self.__lookup.get(function_code, None)
+        return self.__lookup.get(function_code, ExceptionResponse)
 
     def _helper(self, data):
         '''
@@ -118,6 +131,12 @@ class ServerDecoder(IModbusDecoder):
         if not request:
             request = IllegalFunctionRequest(function_code)
         request.decode(data[1:])
+
+        if hasattr(request, 'sub_function_code'):
+            lookup = self.__sub_lookup.get(request.function_code, {})
+            subtype = lookup.get(request.sub_function_code, None)
+            if subtype: request.__class__ = subtype
+
         return request
 
 
@@ -140,6 +159,21 @@ class ClientDecoder(IModbusDecoder):
             WriteSingleCoilResponse,
             ReadWriteMultipleRegistersResponse,
 
+            DiagnosticStatusResponse,
+
+            ReadExceptionStatusResponse,
+            GetCommEventCounterResponse,
+            GetCommEventLogResponse,
+            ReportSlaveIdResponse,
+
+            ReadFileRecordResponse,
+            WriteFileRecordResponse,
+            MaskWriteRegisterResponse,
+            ReadFifoQueueResponse,
+
+            ReadDeviceInformationResponse,
+    ]
+    __sub_function_table = [
             ReturnQueryDataResponse,
             RestartCommunicationsOptionResponse,
             ReturnDiagnosticRegisterResponse,
@@ -158,19 +192,17 @@ class ClientDecoder(IModbusDecoder):
             ClearOverrunCountResponse,
             GetClearModbusPlusResponse,
 
-            ReadExceptionStatusResponse,
-            GetCommEventCounterResponse,
-            GetCommEventLogResponse,
-            ReportSlaveIdResponse,
-
-            ReadFileRecordResponse,
-            WriteFileRecordResponse,
-            MaskWriteRegisterResponse,
-            ReadFifoQueueResponse,
-
             ReadDeviceInformationResponse,
     ]
-    __lookup = dict([(f.function_code, f) for f in __function_table])
+
+    def __init__(self):
+        ''' Initializes the client lookup tables
+        '''
+        functions = set(f.function_code for f in self.__function_table)
+        self.__lookup = dict([(f.function_code, f) for f in self.__function_table])
+        self.__sub_lookup = dict((f, {}) for f in functions)
+        for f in self.__sub_function_table:
+            self.__sub_lookup[f.function_code][f.sub_function_code] = f
 
     def lookupPduClass(self, function_code):
         ''' Use `function_code` to determine the class of the PDU.
@@ -178,7 +210,7 @@ class ClientDecoder(IModbusDecoder):
         :param function_code: The function code specified in a frame.
         :returns: The class of the PDU that has a matching `function_code`.
         '''
-        return self.__lookup.get(function_code, None)
+        return self.__lookup.get(function_code, ExceptionResponse)
 
     def decode(self, message):
         ''' Wrapper to decode a response packet
@@ -210,6 +242,12 @@ class ClientDecoder(IModbusDecoder):
         if not response:
             raise ModbusException("Unknown response %d" % function_code)
         response.decode(data[1:])
+
+        if hasattr(response, 'sub_function_code'):
+            lookup = self.__sub_lookup.get(response.function_code, {})
+            subtype = lookup.get(response.sub_function_code, None)
+            if subtype: response.__class__ = subtype
+
         return response
 
 #---------------------------------------------------------------------------#
