@@ -6,13 +6,14 @@ A collection of utilities for building and decoding
 modbus messages payloads.
 '''
 from struct import pack, unpack
+from pymodbus.interfaces import IPayloadBuilder
 from pymodbus.constants import Endian
 from pymodbus.utilities import pack_bitstring
 from pymodbus.utilities import unpack_bitstring
 from pymodbus.exceptions import ParameterException
 
 
-class PayloadBuilder(object):
+class BinaryPayloadBuilder(IPayloadBuilder):
     '''
     A utility that helps build payload messages to be
     written with the various modbus messages. It really is just
@@ -20,10 +21,10 @@ class PayloadBuilder(object):
     time looking up the format strings. What follows is a simple
     example::
 
-        builder = PayloadBuilder(endian=Endian.Little)
+        builder = BinaryPayloadBuilder(endian=Endian.Little)
         builder.add_8bit_uint(1)
         builder.add_16bit_uint(2)
-        payload = builder.tostring()
+        payload = builder.build()
     '''
 
     def __init__(self, payload=None, endian=Endian.Little):
@@ -35,19 +36,19 @@ class PayloadBuilder(object):
         self._payload = payload or []
         self._endian  = endian
 
-    def reset(self):
-        ''' Reset the payload buffer
-        '''
-        self._payload = []
-
-    def tostring(self):
+    def __str__(self):
         ''' Return the payload buffer as a string
 
         :returns: The payload buffer as a string
         '''
         return ''.join(self._payload)
 
-    def tolist(self):
+    def reset(self):
+        ''' Reset the payload buffer
+        '''
+        self._payload = []
+
+    def build(self):
         ''' Return the payload buffer as a list
 
         This list is two bytes per element and can
@@ -55,7 +56,7 @@ class PayloadBuilder(object):
 
         :returns: The payload buffer as a list
         '''
-        string = self.tostring()
+        string = str(self)
         length = len(string)
         string = string + ('\x00' * (length % 2))
         return [string[i:i+2] for i in xrange(0, length, 2)]
@@ -69,7 +70,6 @@ class PayloadBuilder(object):
 
         :param value: The value to add to the buffer
         '''
-# TODO endianess issue here
         value = pack_bitstring(values)
         self._payload.append(value)
 
@@ -163,14 +163,14 @@ class PayloadBuilder(object):
             self._payload.append(pack(fstring, c))
 
 
-class PayloadDecoder(object):
+class BinaryPayloadDecoder(object):
     '''
     A utility that helps decode payload messages from a modbus
     reponse message.  It really is just a simple wrapper around
     the struct module, however it saves time looking up the format
     strings. What follows is a simple example::
 
-        decoder = PayloadDecoder(self.little_endian_payload)
+        decoder = BinaryPayloadDecoder(payload)
         first   = decoder.decode_8bit_uint()
         second  = decoder.decode_16bit_uint()
     '''
@@ -185,25 +185,26 @@ class PayloadDecoder(object):
         self._pointer = 0x00
         self._endian  = endian
 
-    @staticmethod
-    def fromRegisters(registers, endian=Endian.Little):
+    @classmethod
+    def fromRegisters(klass, registers, endian=Endian.Little):
         ''' Initialize a payload decoder with the result of
         reading a collection of registers from a modbus device.
 
         The registers are treated as a list of 2 byte values.
+        We have to do this because of how the data has already
+        been decoded by the rest of the library.
 
         :param registers: The register results to initialize with
         :param endian: The endianess of the payload
         :returns: An initialized PayloadDecoder
         '''
-        fstring = endian + 'H'
-        if isinstance(registers, list):
-            payload = ''.join(pack(fstring, x) for x in registers)
-            return PayloadDecoder(payload, endian)
+        if isinstance(registers, list): # repack into flat binary
+            payload = ''.join(pack('>H', x) for x in registers)
+            return klass(payload, endian)
         raise ParameterException('Invalid collection of registers supplied')
 
-    @staticmethod
-    def fromCoils(coils, endian=Endian.Little):
+    @classmethod
+    def fromCoils(klass, coils, endian=Endian.Little):
         ''' Initialize a payload decoder with the result of
         reading a collection of coils from a modbus device.
 
@@ -214,9 +215,8 @@ class PayloadDecoder(object):
         :returns: An initialized PayloadDecoder
         '''
         if isinstance(coils, list):
-# TODO endianess issue here
             payload = pack_bitstring(coils)
-            return PayloadDecoder(payload, endian)
+            return klass(payload, endian)
         raise ParameterException('Invalid collection of coils supplied')
 
     def reset(self):
@@ -230,12 +230,11 @@ class PayloadDecoder(object):
         self._pointer += 1
         fstring = self._endian + 'B'
         handle = self._payload[self._pointer - 1:self._pointer]
-        return unpack('B', handle)[0]
+        return unpack(fstring, handle)[0]
 
     def decode_bits(self):
         ''' Decodes a byte worth of bits from the buffer
         '''
-# TODO endianess issue here
         self._pointer += 1
         fstring = self._endian + 'B'
         handle = self._payload[self._pointer - 1:self._pointer]
@@ -324,4 +323,4 @@ class PayloadDecoder(object):
 #---------------------------------------------------------------------------#
 # Exported Identifiers
 #---------------------------------------------------------------------------#
-__all__ = ["PayloadBuilder", "PayloadDecoder"]
+__all__ = ["BinaryPayloadBuilder", "BinaryPayloadDecoder"]
