@@ -14,7 +14,7 @@ from pymodbus.datastore import ModbusServerContext
 from pymodbus.device import ModbusControlBlock
 from pymodbus.device import ModbusDeviceIdentification
 from pymodbus.transaction import *
-from pymodbus.exceptions import ModbusException, NotImplementedException
+from pymodbus.exceptions import NotImplementedException
 from pymodbus.pdu import ModbusExceptions as merror
 
 #---------------------------------------------------------------------------#
@@ -201,7 +201,7 @@ class ModbusTcpServer(SocketServer.ThreadingTCPServer):
     server context instance.
     '''
 
-    def __init__(self, context, framer=None, identity=None):
+    def __init__(self, context, framer=None, identity=None, address=None):
         ''' Overloaded initializer for the socket server
 
         If the identify structure is not passed in, the ModbusControlBlock
@@ -210,19 +210,20 @@ class ModbusTcpServer(SocketServer.ThreadingTCPServer):
         :param context: The ModbusServerContext datastore
         :param framer: The framer strategy to use
         :param identity: An optional identify structure
-
+        :param address: An optional (interface, port) to bind to.
         '''
         self.threads = []
         self.decoder = ServerDecoder()
         self.framer  = framer  or ModbusSocketFramer
         self.context = context or ModbusServerContext()
         self.control = ModbusControlBlock()
+        self.address = address or ("", Defaults.Port)
 
         if isinstance(identity, ModbusDeviceIdentification):
             self.control.Identity.update(identity)
 
         SocketServer.ThreadingTCPServer.__init__(self,
-            ("", Defaults.Port), ModbusConnectedRequestHandler)
+            self.address, ModbusConnectedRequestHandler)
 
     def process_request(self, request, client):
         ''' Callback for connecting a new client thread
@@ -251,7 +252,7 @@ class ModbusUdpServer(SocketServer.ThreadingUDPServer):
     server context instance.
     '''
 
-    def __init__(self, context, framer=None, identity=None):
+    def __init__(self, context, framer=None, identity=None, address=None):
         ''' Overloaded initializer for the socket server
 
         If the identify structure is not passed in, the ModbusControlBlock
@@ -260,19 +261,20 @@ class ModbusUdpServer(SocketServer.ThreadingUDPServer):
         :param context: The ModbusServerContext datastore
         :param framer: The framer strategy to use
         :param identity: An optional identify structure
-
+        :param address: An optional (interface, port) to bind to.
         '''
         self.threads = []
         self.decoder = ServerDecoder()
         self.framer  = framer  or ModbusSocketFramer
         self.context = context or ModbusServerContext()
         self.control = ModbusControlBlock()
+        self.address = address or ("", Defaults.Port)
 
         if isinstance(identity, ModbusDeviceIdentification):
             self.control.Identity.update(identity)
 
         SocketServer.ThreadingUDPServer.__init__(self,
-            ("", Defaults.Port), ModbusDisconnectedRequestHandler)
+            self.address, ModbusDisconnectedRequestHandler)
 
     def process_request(self, request, client):
         ''' Callback for connecting a new client thread
@@ -387,25 +389,27 @@ class ModbusSerialServer(object):
 #---------------------------------------------------------------------------#
 # Creation Factories
 #---------------------------------------------------------------------------#
-def StartTcpServer(context=None, identity=None):
+def StartTcpServer(context=None, identity=None, address=None):
     ''' A factory to start and run a tcp modbus server
 
     :param context: The ModbusServerContext datastore
     :param identity: An optional identify structure
+    :param address: An optional (interface, port) to bind to.
     '''
     framer = ModbusSocketFramer
-    server = ModbusTcpServer(context, framer, identity)
+    server = ModbusTcpServer(context, framer, identity, address)
     server.serve_forever()
 
 
-def StartUdpServer(context=None, identity=None):
+def StartUdpServer(context=None, identity=None, address=None):
     ''' A factory to start and run a udp modbus server
 
     :param context: The ModbusServerContext datastore
     :param identity: An optional identify structure
+    :param address: An optional (interface, port) to bind to.
     '''
     framer = ModbusSocketFramer
-    server = ModbusUdpServer(context, framer, identity)
+    server = ModbusUdpServer(context, framer, identity, address)
     server.serve_forever()
 
 
